﻿* Encoding: UTF-8.
/*****************************************************************************
/*
/*            INSTITUTO NACIONAL PARA LA EVALUACIÓN DE LA EDUCACIÓN
/*             UNIDAD DE EVALUACIÓN DEL SISTEMA EDUCATIVO NACIONAL
/*             DIRECCIÓN GENERAL DE MEDICIÓN Y TRATAMIENTO DE DATOS
/*
/*                      DIRECCIÓN DE TRATAMIENTO DE DATOS
/*
/*_______________________________________________________________________
/*
/*                            EVOE-ECEA
/*                            PREESCOLAR
/*
/*                        **** DOCENTES ****
/*                         ***UNIFICADA***
/*_____________________________________________________________________________
/*
/*
/*        SINTAXIS PARA ETIQUETAR LA TABLA DE DATOS DE DOCENTE DE GRUPO
/*                  EN FORMATO SPSS PARA ECEA00, 2017
/*_____________________________________________________________________________
/*
/*  La sintaxis etiqueta las variables así como sus valores y declara los
/*  valores perdidos (missing values)
/*
/* INSTRUCCIONES
/*  Para etiquetar la base de datos (tabla de datos) es necesario:
/*      1) Abrir la tabla de en formato SPSS y el archivo de sintaxis
/*      2) Ejecutar toda la sintaxis del archivo.
/*
/*  Al finalizar el ejecución del sintaxis, la tabla ECEA00_2017_Docentes_Unificada.SAV
/*  quedará etiquetada.
/*
/* CONTACTO:
/*
/*      Para mayor información o aclaración de dudas favor de contactar a la
/*      Dirección de Tratamiento de Datos
/*      Correo electrónico: analisis@inee.edu.mx
/*      Tel 5482 0900 Ext. 32025
/*      Domicilio: Av. Barranca del Muerto no. 341, 3er piso. Col. San José Insurgentes
/*                 Del. Benito Juárez. Ciudad de México
/*
/* FECHA DE LIBERACIÓN:  5 de abril de 2019
/*
/*  ****************************************************************************/

/***********************************************************************
/*       Etiquetas de variables
/*
/**********************************************************************.

VARIABLE LABELS
     NACIONAL              "Variable auxiliar para obtener promedios nacionales"
     FOL_DOC               "Identificador del Docente"
     ESCUELA               "Identificador de la escuela"
     NIVEL                 "Nivel educativo"
     ID_ENT                "Entidad federativa (identificador numérico)"
     NOM_ENT               "Entidad federativa"
     ID_TURNO              "Identificador numérico del turno escolar"
     TURNO                 "Turno de la escuela"
     ID_PREESTRATO         "Identificador numérico del preestrato"
     PREESTRATO            "Dominio de interés"
     W_FGRPWT              "Peso muestral final del docente"
     ENU01a                "En este preescolar y turno, ¿qué grados atiende en su grupo? Primer grado"
     ENU01b                "En este preescolar y turno, ¿qué grados atiende en su grupo? Segundo grado"
     ENU01c                "En este preescolar y turno, ¿qué grados atiende en su grupo? Tercer grado"
     ENU02a                "Al día de hoy, ¿cuántas niñas y niños tiene en su grupo? Niñas"
     ENU02b                "Al día de hoy, ¿cuántas niñas y niños tiene en su grupo? Niños"
     ENU03                 "En su grupo, ¿cuántas niñas y niños hablan algún dialecto o lengua indígena? Total de niñas y niños hablantes de algún dialecto o lengua indígena"
     ENU04                 "En su grupo, ¿cuántas niñas y niños tienen alguna discapacidad diagnosticada? Total de niñas y niños que tienen alguna discapacidad diagnosticada"
     ENU04_1               "En este preescolar, ¿hay niñas y niños con alguna discapacidad?"
     ENU05                 "En su grupo, ¿cuántas niñas y niños tienen alguna discapacidad visual diagnosticada (ceguera y baja visión)? Total de niñas y niños que tienen alguna discapacidad visual"
     ENU05a                "¿Cuántas niñas y niños hay con las siguientes discapacidades? Ceguera, es decir, que no ven"
     ENU05b                "¿Cuántas niñas y niños hay con las siguientes discapacidades? Baja visión, es decir, que no ven bien ni con lentes o anteojos. No cuente a los niños que regularmente usan lentes"
     ENU06                 "En su grupo, ¿cuántas niñas y niños tienen alguna discapacidad auditiva diagnosticada (sordera y baja audición)? Total de niñas y niños que tienen alguna discapacidad auditiva"
     ENU06a                "¿Cuántas niñas y niños hay con las siguientes discapacidades? Sordera diagnosticada por un especialista, es decir, que no oyen"
     ENU06b                "¿Cuántas niñas y niños hay con las siguientes discapacidades? Baja audición diagnosticada por un especialista, es decir, que no oyen bien ni con auxiliar auditivo"
     ENU07                 "Durante el ciclo escolar 2017-2018, ¿a cuántas niñas y niños de su grupo les ha llegado el libro de texto gratuito Mi álbum. Preescolar, del grado correspondiente? Total de niñas y niños que han recibido... (ver cuestionario .pdf)"
     ENU08                 "En su salón de clases, ¿cuántas niñas y niños tienen silla para sentarse? Total de niñas y niños que tienen silla para sentarse"
     ENU09                 "El tamaño de su salón de clases es:"
     ENU10                 "El tamaño de su salón de clases, ¿permite el movimiento o desplazamiento de niñas y niños para el desarrollo de las actividades educativas?"
     ENU11                 "¿La ventilación de su salón de clases es adecuada durante el desarrollo de las actividades?"
     ENU12                 "¿Su salón de clases requiere algún tipo de clima artificial como aire acondicionado o calefacción?"
     ENU13                 "¿La iluminación de su salón de clases es suficiente para el desarrollo de las actividades?"
     ENU14                 "En su salón de clases, ¿dispone de energía eléctrica?"
     ENU15                 "¿Qué tanto interfieren los ruidos exteriores del entorno en el desarrollo de las actividades dentro de su salón de clases?"
     ENU16a                "En su salón de clases, ¿en qué condiciones se encuentran el techo, los muros o las paredes y el piso? Techo"
     ENU16b                "En su salón de clases, ¿en qué condiciones se encuentran el techo, los muros o las paredes y el piso? Muros o Paredes"
     ENU16c                "En su salón de clases, ¿en qué condiciones se encuentran el techo, los muros o las paredes y el piso? Piso"
     ENU17                 "En su salón de clases, ¿las condiciones en que se encuentra el pizarrón o pintarrón permiten escribir sin dificultad?"
     ENU18                 "En su salón de clases, ¿cuántas sillas tienen la altura adecuada a la estatura de las niñas y los niños de su grupo?"
     ENU19                 "En su salón de clases, ¿cuántas sillas que utilizan niñas y niños están en buenas condiciones, es decir, no presentan deterioro y su uso no representa riesgo?"
     ENU20                 "En su salón de clases, ¿hacen falta mesas para que todas las niñas y los niños realicen las actividades educativas que usted propone?"
     ENU21                 "En su salón de clases, ¿a cuántas niñas y niños les hace falta mesa para que realicen las actividades educativas que usted propone?"
     ENU22                 "En su salón de clases, ¿las mesas tienen la altura adecuada a la estatura de las niñas y los niños de su grupo?"
     ENU23                 "Las mesas de su salón de clases, ¿se pueden acomodar de distintas formas para facilitar las actividades en equipo de niñas y niños?"
     ENU24                 "En su salón de clases, ¿cuántas mesas que utilizan niñas y niños para realizar sus actividades educativas están en buenas condiciones, es decir, no presentan deterioro y su uso no representa riesgo?"
     ENU25                 "En su salón de clases, ¿usted cuenta con silla?"
     ENU26                 "En su salón de clases, ¿en qué condiciones está la silla que usted utiliza?"
     ENU27                 "En su salón de clases, ¿usted cuenta con escritorio o mesa?"
     ENU28                 "En su salón de clases, ¿en qué condiciones está el escritorio o mesa que usted utiliza?"
     ENU29                 "En su salón de clases, ¿cuenta con mobiliario para organizar o guardar el material didáctico o equipo?"
     ENU30                 "En su salón de clases, ¿en qué condiciones se encuentra el mobiliario para organizar o guardar el material didáctico o equipo?"
     ENU31                 "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con el Programa de estudio 2011.Guía para la Educadora?"
     ENU32                 "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con el Libro de la Educadora?"
     ENU32_1a              "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con los siguientes libros? Unidades de Aprendizaje Autónomo. Lenguaje y Comunicación"
     ENU32_1b              "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con los siguientes libros? Unidades de Aprendizaje Autónomo. Pensamiento Matemático"
     ENU32_1c              "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con los siguientes libros? Unidades de Aprendizaje Autónomo. Exploración y Comprensión del Mundo Natural"
     ENU32_1d              "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con los siguientes libros? Unidades de Aprendizaje Autónomo. Exploración y Comprensión del Mundo Social"
     ENU32_1e              "Durante el ciclo escolar 2017-2018, ¿se han realizado las siguientes acciones para la promoción de la salud de niñas y niños de este preescolar comunitario? Otra acción"
     ENU33                 "¿Cuenta con biblioteca de aula o libros en el espacio de biblioteca? No cuente los libros de texto, de ejercicios o para colorear y recortar."
     ENU34                 "¿Cuántos libros hay aproximadamente en la biblioteca?"
     ENU35                 "¿Cuántos libros de la biblioteca estan en buenas condiciones?"
     ENU36a                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Material específico para la atención de niñas ... (ver cuestionario .pdf)"
     ENU36b                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Material específico para la atención de niñas ... (ver cuestionario .pdf)"
     ENU36c                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Materiales didácticos en lengua indígena ... (ver cuestionario .pdf)"
     ENU36d                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Material de construcción o ensamble (cubos, blocks, legos u otros)"
     ENU36e                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Material para actividades físicas y deportivas ... (ver cuestionario .pdf)"
     ENU36f                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Material para dramatización (disfraces, ... (ver cuestionario .pdf)"
     ENU36g                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Materiales para observación y experimentación ... (ver cuestionario .pdf)"
     ENU36h                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Material para apreciación de arte visual ... (ver cuestionario .pdf)"
     ENU36i                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Láminas de distintos temas (de las estaciones... (ver cuestionario .pdf)"
     ENU36j                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Juegos de mesa (tangram, dominó, dados, lotería, rompecabezas u otros)"
     ENU36k                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Juguetes varios (cubetas, vasijas, palas, ... (ver cuestionario .pdf)"
     ENU36l                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Juegos didácticos para computadora"
     ENU36m                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Cuerpos geométricos tridimensionales o geoplano"
     ENU36n                "¿Considera suficientes o insuficientes los diferentes tipos de materiales que existen en su preescolar para realizar las actividades escolares con su grupo? Instrumentos musicales y música de distintos géneros y estilos"
     ENU37a                "En general, en una jornada de clases con su grupo, ¿qué porcentaje de tiempo dedica a las siguientes actividades? % situaciones de aprendizaje de los campos formativos"
     ENU37b                "En general, en una jornada de clases con su grupo, ¿qué porcentaje de tiempo dedica a las siguientes actividades? % actividades cotidianas (bienvenida, pase de lista, actividad de higiene, despedida)"
     ENU37c                "En general, en una jornada de clases con su grupo, ¿qué porcentaje de tiempo dedica a las siguientes actividades? % actividades de apoyo al currículo (educación física, música y movimiento, enseñanza del ... (ver cuestionario .pdf)"
     ENU37d                "En general, en una jornada de clases con su grupo, ¿qué porcentaje de tiempo dedica a las siguientes actividades? % actividades administrativas (llenado de documentación, solicitudes de la dirección... (ver cuestionario .pdf)"
     ENU37e                "En general, en una jornada de clases con su grupo, ¿qué porcentaje de tiempo dedica a las siguientes actividades? % acciones para mantener el orden del grupo"
     ENU38a                "Al inicio de este ciclo escolar (2017-2018), ¿realizó alguna de las siguientes acciones para explorar o identificarlo que saben y pueden hacer las niñas y los niños de su grupo? Observar a niñas y niños... (ver cuestionario .pdf)"
     ENU38b                "Al inicio de este ciclo escolar (2017-2018), ¿realizó alguna de las siguientes acciones para explorar o identificarlo que saben y pueden hacer las niñas y los niños de su grupo? Revisar el Reporte de Evaluación"
     ENU38c                "Al inicio de este ciclo escolar (2017-2018), ¿realizó alguna de las siguientes acciones para explorar o identificarlo que saben y pueden hacer las niñas y los niños de su grupo? Revisar los expedientes de... (ver cuestionario .pdf)"
     ENU38d                "Al inicio de este ciclo escolar (2017-2018), ¿realizó alguna de las siguientes acciones para explorar o identificarlo que saben y pueden hacer las niñas y los niños de su grupo? Aplicar ejercicios de... (ver cuestionario .pdf)"
     ENU38e                "Al inicio de este ciclo escolar (2017-2018), ¿realizó alguna de las siguientes acciones para explorar o identificarlo que saben y pueden hacer las niñas y los niños de su grupo? Aplicar exámenes diagnósticos"
     ENU38f                "Al inicio de este ciclo escolar (2017-2018), ¿realizó alguna de las siguientes acciones para explorar o identificarlo que saben y pueden hacer las niñas y los niños de su grupo? Entrevistar a los padres de familia"
     ENU38g                "Al inicio de este ciclo escolar (2017-2018), ¿realizó alguna de las siguientes acciones para explorar o identificarlo que saben y pueden hacer las niñas y los niños de su grupo? Otra acción"
     ENU39                 "Principalmente, ¿cómo elabora su planificación, plan o ficha de trabajo para el desarrollo de actividades con su grupo?"
     ENU40a                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Programa de estudio 2011 de Preescolar"
     ENU40b                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Guía para la Educadora (incluido en el Programa de estudio 2011)"
     ENU40c                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Libro Mi álbum. Preescolar del grado o grados que imparte"
     ENU40d                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Libro de la Educadora (para trabajar con el libro Mi álbum. Preescolar)"
     ENU40e                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Guías del Consejo Técnico Escolar"
     ENU40f                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Guías y materiales de los programas de la sep en los que participa el preescolar"
     ENU40g                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Libros de texto de otras editoriales"
     ENU40h                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Libros del Marco Curricular de la Educación Preescolar Indígena y de la Población Migrante"
     ENU40i                "Para la elaboración de su planificación o plan de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Otro material"
     ENU40j                "Para la elaboración de su planificación, plan o ficha de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Las Unidades de Aprendizaje Autónomo (UAA) para cada campo formativo"
     ENU40k                "Para la elaboración de su planificación, plan o ficha de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Recomendaciones y estrategias para la implementación del ABCD con los más pequeños"
     ENU40l                "Para la elaboración de su planificación, plan o ficha de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Libro Único: Para aprender a leer, escribir y contar"
     ENU40m                "Para la elaboración de su planificación, plan o ficha de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Libro Fortalecimiento de la lengua y culturas indígenas y taller lingüístico en el ABCD"
     ENU40n                "Para la elaboración de su planificación, plan o ficha de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Actividades de trabajo para el preescolar comunitario. Fichas"
     ENU40o                "Para la elaboración de su planificación, plan o ficha de trabajo, ¿cuáles de los siguientes libros o documentos utiliza? Aprendo con mi nombre. Guía para enseñar a leer a partir del nombre propio"
     ENU41a                "En las últimas cuatro semanas, ¿con qué frecuencia realizó las siguientes acciones durante las actividades de aprendizaje para fomentar la interacción entre los integrantes de su grupo? Organicé a niñas... (ver cuestionario .pdf)"
     ENU41b                "En las últimas cuatro semanas, ¿con qué frecuencia realizó las siguientes acciones durante las actividades de aprendizaje para fomentar la interacción entre los integrantes de su grupo? Solicité a una niña... (ver cuestionario .pdf)"
     ENU41c                "En las últimas cuatro semanas, ¿con qué frecuencia realizó las siguientes acciones durante las actividades de aprendizaje para fomentar la interacción entre los integrantes de su grupo? Pedí a una niña o... (ver cuestionario .pdf)"
     ENU41d                "En las últimas cuatro semanas, ¿con qué frecuencia realizó las siguientes acciones durante las actividades de aprendizaje para fomentar la interacción entre los integrantes de su grupo? Realicé asambleas... (ver cuestionario .pdf)"
     ENU41e                "En las últimas cuatro semanas, ¿con qué frecuencia realizó las siguientes acciones durante las actividades de aprendizaje para fomentar la interacción entre los integrantes de su grupo? Organicé actividades... (ver cuestionario .pdf)"
     ENU41f                "En las últimas cuatro semanas, ¿con qué frecuencia realizó las siguientes acciones durante las actividades de aprendizaje para fomentar la interacción entre los integrantes de su grupo? Organicé juegos en... (ver cuestionario .pdf)"
     ENU42                 "Principalmente, ¿qué hace durante la clase cuando alguna niña o niño no entiende una actividad o se le dificulta realizarla?"
     ENU43a                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia ha utilizado la evaluación realizada a niñas y niños con los siguientes propósitos? Informar a los padres de familia o tutores sobre el desempeño de sus hijas o hijos"
     ENU43b                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia ha utilizado la evaluación realizada a niñas y niños con los siguientes propósitos? Identificar los avances y las dificultades de niñas y niños en el desarrollo de competencias"
     ENU43c                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia ha utilizado la evaluación realizada a niñas y niños con los siguientes propósitos? Tener información sobre el desempeño de niñas y niños para el... (ver cuestionario .pdf)"
     ENU43d                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia ha utilizado la evaluación realizada a niñas y niños con los siguientes propósitos? Proporcionar apoyo a niñas y niños en sus aprendizajes"
     ENU43e                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia ha utilizado la evaluación realizada a niñas y niños con los siguientes propósitos? Obtener información para modificar mi plan de trabajo y actividades de enseñanza"
     ENU44a                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Platiquen entre compañeras y compañeros sobre cómo se sienten"
     ENU44b                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Realicen juego de roles y representen un personaje"
     ENU44c                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Utilicen diferentes estrategias para encontrar solución a un problema o a un juego"
     ENU44d                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Inventen un cuento"
     ENU44e                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Estimen diferentes resultados a través de ensayo y error para resolver un problema o un juego"
     ENU44f                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Expresen a otros sus ideas y conocimientos acerca de los fenómenos o seres de la naturaleza"
     ENU44g                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Copien letras o palabras"
     ENU44h                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Expliquen a otros su opinión acerca de las producciones propias o de sus compañeras y... (ver cuestionario .pdf)"
     ENU44i                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Participen en acciones de promoción del cuidado del medio ambiente (elaboración de composta... (ver cuestionario .pdf)"
     ENU44j                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Realicen juegos donde sigan reglas establecidas (dominó, lotería, serpientes y escaleras u otro)"
     ENU44k                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Expresen semejanzas y diferencias entre las costumbres de su comunidad con respecto a otros lugares"
     ENU44l                "En las últimas cuatro semanas, ¿con qué frecuencia ha solicitado que su grupo realice las siguientes actividades? Coloreen dibujos impresos"
     ENU45a                "En este preescolar, ¿con cuáles de los siguientes reglamentos se cuenta? Reglamento escolar escrito: Contiene las reglas, normas o los acuerdos que regulan las actividades y los comportamientos de la ... (ver cuestionario .pdf)"
     ENU45b                "¿Cuenta con reglamento del salón de clases (también denominado reglas, normas o acuerdos que regulan las actividades y comportamientos de niñas, niños y docentes en el salón de clases)?"
     ENU46                 "¿Quién elaboró el reglamento del salón de clases?"
     ENU47a                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Fomento de valores como respetar, compartir, apoyar u otro"
     ENU47b                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Indicaciones para conservar el orden en el salón de clases"
     ENU47c                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Presentación, arreglo y aseo personal de niñas y niños"
     ENU47d                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Hábitos de cortesía"
     ENU47e                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Aspectos sobre los que niñas y niños deberán solicitar permiso"
     ENU47f                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Conductas que se deben evitar en el salón de clases"
     ENU47g                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Acciones para cuidar el mobiliario y espacios comunes del preescolar"
     ENU47h                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Acciones para el cuidado del medio ambiente"
     ENU47i                "¿Cuáles de los siguientes aspectos se incluyen en el reglamento del salón de clases? Otro aspecto"
     ENU48a                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Escuchan a sus compañeras y compañeros mientras participan en las actividades de clase"
     ENU48b                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Toman materiales o juguetes que está usando alguna compañera o compañero sin pedírselo"
     ENU48c                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Se muestran dispuestos a trabajar con sus compañeras y compañeros"
     ENU48d                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Comparten sus materiales y juguetes con sus compañeras y compañeros"
     ENU48e                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Se ayudan durante las actividades"
     ENU48f                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Cuidan a sus compañeras y compañeros en las actividades educativas y de juego"
     ENU48g                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Molestan o rechazan a una compañera o un compañero"
     ENU48h                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Agreden físicamente a compañeras o compañeros"
     ENU48i                "En una jornada regular de clases, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones? Agreden verbalmente a compañeras o compañeros"
     ENU49a                "En general, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones con otras niñas o niños del preescolar? Juegan con niñas y niños en el recreo"
     ENU49b                "En general, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones con otras niñas o niños del preescolar? Juegan con niñas y niños en horario de entrada o salida de clases"
     ENU49c                "En general, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones con otras niñas o niños del preescolar? Respetan su turno cuando comparten juguetes, juegos o espacios comunes con niñas y niños del preescolar"
     ENU49d                "En general, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones con otras niñas o niños del preescolar? Cuidan a niñas y niños de la escuela cuando se encuentran en espacios comunes (baños, patio, escaleras, u otro)"
     ENU49e                "En general, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones con otras niñas o niños del preescolar? Molestan o intimidan a niñas y niños de la escuela en espacios comunes (baños, patio, escaleras, u otro)"
     ENU49f                "En general, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones con otras niñas o niños del preescolar? Agreden físicamente a niñas y niños de la escuela en espacios comunes (baños, patio, escaleras u otro)"
     ENU49g                "En general, ¿cuántas niñas y niños de su grupo realizan las siguientes acciones con otras niñas o niños del preescolar? Agreden verbalmente a niñas y niños de la escuela en espacios comunes (baños, patio, escaleras u otro)"
     ENU50                 "En general, ¿cuántos padres de familia la tratan de manera respetuosa?"
     ENU51                 "¿Usted es docente de un preescolar de educación indígena?"
     ENU52a                "¿Qué tanto domina la variante de la lengua indígena que habla la mayoría de niñas y niños de su grupo? En mi grupo nadie habla una lengua indígena"
     ENU52b                "¿Qué tanto domina la variante de la lengua indígena que habla la mayoría de niñas y niños de su grupo? Entiendo"
     ENU52c                "¿Qué tanto domina la variante de la lengua indígena que habla la mayoría de niñas y niños de su grupo? Hablo"
     ENU52d                "¿Qué tanto domina la variante de la lengua indígena que habla la mayoría de niñas y niños de su grupo? Leo"
     ENU52e                "¿Qué tanto domina la variante de la lengua indígena que habla la mayoría de niñas y niños de su grupo? Escribo"
     ENU53                 "Durante el ciclo escolar 2017-2018, ¿a cuántas niñas y niños de su grupo les ha llegado el libro de texto gratuito Juegos y materiales educativos de la niñez indígena y migrante. Cuaderno del alumno? ... (ver cuestionario .pdf)"
     ENU54                 "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿usted cuenta con el libro Juegos y materiales educativos de la niñez indígena y migrante. Preescolar. Guía-Cuaderno del docente?"
     ENU55a                "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con los siguientes fascículos del Marco Curricular de la Educación Preescolar Indígena y de la Población Migrante? Marco Curricular... (ver cuestionario .pdf)"
     ENU55b                "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con los siguientes fascículos del Marco Curricular de la Educación Preescolar Indígena y de la Población Migrante? Marco Curricular... (ver cuestionario .pdf)"
     ENU55c                "Desde el primer día de clases de este ciclo escolar (2017-2018), ¿cuenta con los siguientes fascículos del Marco Curricular de la Educación Preescolar Indígena y de la Población Migrante? Diversificación y... (ver cuestionario .pdf)"
     ENU56a                "En este preescolar, ¿cómo se retroalimenta la práctica docente entre compañeras? En pláticas o consultas cotidianas como horarios de descanso, en el recreo u otro momento"
     ENU56b                "En este preescolar, ¿cómo se retroalimenta la práctica docente entre compañeras? En el Consejo Técnico Escolar"
     ENU56c                "En este preescolar, ¿cómo se retroalimenta la práctica docente entre compañeras? En reuniones programadas por la dirección, distintas al Consejo Técnico Escolar (semanales u otro momento)"
     ENU56d                "En este preescolar, ¿cómo se retroalimenta la práctica docente entre compañeras? En reuniones organizadas por las docentes"
     ENU56e                "En este preescolar, ¿cómo se retroalimenta la práctica docente entre compañeras? En espacios virtuales como en redes sociales, blogs, foros u otro"
     ENU56f                "En este preescolar, ¿cómo se retroalimenta la práctica docente entre compañeras? En otro espacio"
     ENU57a                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Organizar eventos escolares recreativos... (ver cuestionario .pdf)"
     ENU57b                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Revisar el plan de trabajo escolar (Ruta... (ver cuestionario .pdf)"
     ENU57c                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Elaborar, analizar o adecuar el reglamento escolar"
     ENU57d                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Analizar las situaciones escolares que... (ver cuestionario .pdf)"
     ENU57e                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Generar estrategias escolares para apoyar... (ver cuestionario .pdf)"
     ENU57f                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa?  Elaborar estrategias pedagógicas para... (ver cuestionario .pdf)"
     ENU57g                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Dar seguimiento a los avances de niñas... (ver cuestionario .pdf)"
     ENU57h                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Acordar las actividades de actualización y... (ver cuestionario .pdf)"
     ENU57i                "Durante el ciclo escolar 2017-2018, ¿con qué frecuencia las otras docentes o la directora y usted han realizado las siguientes actividades de manera colaborativa? Analizar la práctica de las docentes a... (ver cuestionario .pdf)"
     ENU58a                "¿Los siguientes aspectos representan obstáculos para realizar el trabajo colaborativo dentro de este preescolar? Poco interés de las docentes hacia el trabajo colaborativo"
     ENU58b                "¿Los siguientes aspectos representan obstáculos para realizar el trabajo colaborativo dentro de este preescolar? Falta de tiempo en la jornada laboral para que las docentes se reúnan"
     ENU58c                "¿Los siguientes aspectos representan obstáculos para realizar el trabajo colaborativo dentro de este preescolar? Falta de promoción del trabajo colaborativo por parte de la directora"
     ENU58d                "¿Los siguientes aspectos representan obstáculos para realizar el trabajo colaborativo dentro de este preescolar? Falta de disposición al diálogo entre las docentes para llegar a acuerdos"
     ENU58e                "¿Los siguientes aspectos representan obstáculos para realizar el trabajo colaborativo dentro de este preescolar? Falta de un espacio físico dentro del preescolar para reunirse"
     ENU58f                "¿Los siguientes aspectos representan obstáculos para realizar el trabajo colaborativo dentro de este preescolar? Otro obstáculo"
     ENU59                 "Durante los dos últimos años, ¿ha participado en cursos, talleres u otras actividades de formación o actualización?"
     ENU60a                "Durante los dos últimos años, ¿ha participado en alguna de las siguientes actividades de formación o actualización? Capacitación en las reuniones de Consejo Técnico Escolar"
     ENU60b                "Durante los dos últimos años, ¿ha participado en alguna de las siguientes actividades de formación o actualización? Cursos, talleres u otras actividades de formación que organiza la escuela (distintos al Consejo Técnico Escolar)"
     ENU60c                "Durante los dos últimos años, ¿ha participado en alguna de las siguientes actividades de formación o actualización? Cursos, talleres u otras actividades de formación que organiza la supervisión escolar"
     ENU60d                "Durante los dos últimos años, ¿ha participado en alguna de las siguientes actividades de formación o actualización? Cursos, talleres u otras actividades de formación que ofrecen las autoridades educativas... (ver cuestionario .pdf)"
     ENU60e                "Durante los dos últimos años, ¿ha participado en alguna de las siguientes actividades de formación o actualización? Cursos, talleres u otras actividades de formación tomados por cuenta propia (que no le... (ver cuestionario .pdf)"
     ENU60f                "Durante los dos últimos años, ¿ha participado en alguna de las siguientes actividades de formación o actualización? Otra actividad"
     ENU61a                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Campos formativos"
     ENU61b                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Planificación o plan de trabajo docente"
     ENU61c                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Evaluación de los aprendizajes"
     ENU61d                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Trabajo multigrado en el aula"
     ENU61e                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Uso de la tecnología en el aula"
     ENU61f                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Atención a la diversidad cultural y lingüística"
     ENU61g                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Atención a niñas y niños con discapacidad"
     ENU61h                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Convivencia escolar o prevención de la violencia"
     ENU61i                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Características del desarrollo de la infancia"
     ENU61j                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Cuidado de la salud y bienestar de la infancia"
     ENU61k                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Los derechos de niñas y niños"
     ENU61l                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Enfoque de género en preescolar"
     ENU61m                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Trabajo con padres de familia"
     ENU61n                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? El Nuevo Modelo Educativo"
     ENU61o                "Durante los dos últimos años, ¿ha recibido formación o actualización en los siguientes temas? Otro tema"
     ENU61_1a              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Trabajo con las Unidades de Aprendizaje Autónomo"
     ENU61_1b              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Planificación, plan o ficha de trabajo"
     ENU61_1c              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Evaluación de los aprendizajes"
     ENU61_1d              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Enfoque y forma de trabajo del modelo ABCD"
     ENU61_1e              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Trabajo multigrado en el aula"
     ENU61_1f              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Uso de la tecnología en el aula"
     ENU61_1g              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Atención a la diversidad cultural y lingüística"
     ENU61_1h              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Atención a niñas y niños con discapacidad"
     ENU61_1i              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Convivencia escolar o prevención de la violencia"
     ENU61_1j              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Características del desarrollo de la infancia"
     ENU61_1k              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Cuidado de la salud y bienestar de la infancia"
     ENU61_1l              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Los derechos de niñas y niños"
     ENU61_1m              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Enfoque de género en preescolar"
     ENU61_1n              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Trabajo con padres de familia"
     ENU61_1o              "En su formación inicial y reuniones de tutoría, ¿en cuáles de los siguientes temas ha recibido formación? Otro tema"
     ENU62a                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿ha recibido asesoría de las siguientes figuras en su preescolar? Supervisora"
     ENU62b                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿ha recibido asesoría de las siguientes figuras en su preescolar? ATP de preescolar"
     ENU62c                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿ha recibido asesoría de las siguientes figuras en su preescolar? ATP de primaria"
     ENU63                 "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿cuántas veces ha recibido asesoría de la supervisora o del ATP en las visitas que ha hecho a su preescolar? asesorías de la supervisora o ATP en el preescolar"
     ENU63_1               "Durante el ciclo escolar 2017-2018, ¿ha recibido asesoría por el capacitador tutor u otra persona de CONAFE en su comunidad?"
     ENU64a                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Elaboración de la... (ver cuestionario .pdf)"
     ENU64b                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Manejo del orden en el grupo"
     ENU64c                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Uso de materiales específicos"
     ENU64d                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Trabajo con los campos formativos"
     ENU64e                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Evaluación de los aprendizajes de niñas y niños"
     ENU64f                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Estrategias para el... (ver cuestionario .pdf)"
     ENU64g                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Atención a niñas y niños con discapacidad"
     ENU64h                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Atención a la diversidad cultural y lingüística"
     ENU64i                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Elaboración de... (ver cuestionario .pdf)"
     ENU64j                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Promoción de la... (ver cuestionario .pdf)"
     ENU64k                "Desde el ciclo escolar 2016-2017 hasta el día de hoy, ¿en cuáles de los siguientes aspectos ha recibido asesoría de la supervisora o de algún ATP durante las visitas a su preescolar? Otro aspecto"
     ENU64_1a              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Elaboración de la planificación, plan o ficha de trabajo"
     ENU64_1b              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Manejo del orden en el grupo"
     ENU64_1c              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Uso de materiales específicos"
     ENU64_1d              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Trabajo con las Unidades de Aprendizaje Autónomo"
     ENU64_1e              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Evaluación de los aprendizajes de niñas y niños"
     ENU64_1f              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Estrategias para el trabajo en grupos multigrado"
     ENU64_1g              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Atención a niñas y niños con discapacidad"
     ENU64_1h              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Atención a la diversidad cultural y lingüística"
     ENU64_1i              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Elaboración de diversos registro... (ver cuestionario .pdf)"
     ENU64_1j              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Promoción de la participación d... (ver cuestionario .pdf)"
     ENU64_1k              "Durante el ciclo escolar 2017-2018, ¿en cuáles de los siguientes aspectos ha recibido asesoría por el capacitador tutor u otra persona del CONAFE durante las visitas al preescolar comunitario? Otro aspecto"
     ENU64_2               "¿Cuántas semanas duró su capacitación inicial para ser Líder para la Educación Comunitaria?"
     ENU64_3               "Durante el ciclo escolar 2017-2018, ¿ha asistido a reuniones de tutoría?"
     ENU65                 "Usted es:"
     ENU66                 "¿Cuántos años cumplidos tiene usted? Años cumplidos"
     ENU67                 "¿Usted habla algún dialecto o lengua indígena?"
     ENU68a                "¿En qué lengua o lenguas aprendió a hablar en su infancia? Español"
     ENU68b                "¿En qué lengua o lenguas aprendió a hablar en su infancia? Una lengua indígena"
     ENU68c                "¿En qué lengua o lenguas aprendió a hablar en su infancia? Otra lengua"
     ENU69                 "De acuerdo con su cultura, ¿usted se considera indígena?"
     ENU70                 "De acuerdo con su cultura, historia y tradiciones, ¿usted se considera negra, es decir, afromexicana o afrodescendiente? Se incluye el término negra debido a que una parte de la población afrodescendiente se reconoce de esa manera."
     ENU71                 "¿Cuál es el nivel máximo de estudios del que obtuvo certificado o título?"
     ENU72                 "¿En qué tipo de licenciatura tiene certificado o título?"
     ENU73                 "¿Cuál de los siguientes estudios cursa en la actualidad?"
     ENU73_1               "¿Cuál de los siguientes estudios cursa en la actualidad?"
     ENU74                 "¿Cuántos años ha trabajado como docente frente a grupo, en escuelas públicas o privadas? Años como docente frente a grupo"
     ENU75                 "Contando este preescolar, ¿en cuántas escuelas públicas o privadas ha trabajado como docente? Escuelas"
     ENU75_1               "En el ciclo escolar 2017-2018, ¿cuándo inició su trabajo con el grupo que actualmente tiene a su cargo en este preescolar comunitario?"
     ENU75_2               "Considerando este ciclo escolar, ¿cuántos ciclos escolares ha sido Líder para la Educación Comunitaria?"
     ENU75_3               "¿Desde cuándo ha sido Líder para la Educación Comunitaria en esta comunidad?"
     ENU75_4               "¿En cuántas comunidades ha sido Líder para la Educación Comunitaria?"
     ENU76                 "¿Cuál es su situación contractual como docente en este preescolar?"
     ENU77                 "¿Cómo obtuvo su plaza de docente actual?"
     ENU78a                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Enfermedad"
     ENU78b                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Asuntos personales"
     ENU78c                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Curso de actualización"
     ENU78d                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Comisión laboral"
     ENU78e                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Comisión sindical"
     ENU78f                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Condiciones del clima o desastres naturales"
     ENU78g                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Condiciones de violencia o inseguridad en la zona"
     ENU78h                "Si tuvo que faltar en las últimas cuatro semanas, ¿cuál fue el motivo? Otro motivo"
     ENU79                 "En las últimas cuatro semanas, ¿cuántos días hábiles tuvo que faltar al preescolar por cualquier motivo? Días"
     ENU80                 "Actualmente, ¿usted está a cargo de la dirección de este preescolar?"
     ENU81                 "De agosto de 2017 a la fecha, ¿cuántas veces ha recibido asesoría pedagógica respecto a su trabajo con el grupo por parte de la directora? Veces"
     ENU82a                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Elaboración de la planificación o plan del trabajo"
     ENU82b                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Manejo del orden en el grupo"
     ENU82c                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Uso de materiales específicos"
     ENU82d                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Trabajo con los campos formativos"
     ENU82e                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Evaluación de los aprendizajes de niñas y niños"
     ENU82f                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Estrategias para trabajo en grupos multigrado"
     ENU82g                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Atención a niñas y niños con discapacidad"
     ENU82h                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Atención a la diversidad cultural y lingüística"
     ENU82i                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Elaboración de diversos registros para el control escolar, como el reporte... (ver cuestionario .pdf)"
     ENU82j                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Promoción de la participación de los padres de familia en el aprendizaje de sus hijas o hijos"
     ENU82k                "De agosto de 2017 a la fecha, ¿la directora le ha dado asesoría sobre su trabajo docente en alguno de los siguientes aspectos? Otro aspecto"
     ENU83a                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Revisa las planificaciones o plan de trabajo"
     ENU83b                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Revisa los materiales de mis niñas y niños: cuadernos, trabajos, portafolios u otros"
     ENU83c                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Visita el salón para observar mi trabajo con el grupo"
     ENU83d                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Revisa los materiales que uso en clase"
     ENU83e                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Me pide que le platique sobre el trabajo que realizo con... (ver cuestionario .pdf)"
     ENU83f                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Se acerca a niñas y niños para conocer cómo se sienten en clase"
     ENU83g                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Platica con los padres de familia para conocer su opinión sobre mi trabajo en clase"
     ENU83h                "De agosto de 2017 a la fecha, ¿la directora ha realizado alguna de las siguientes acciones para conocer el trabajo que usted realiza con su grupo? Otra acción"
     ENU84a                "De agosto de 2017 a la fecha, ¿con qué frecuencia se han presentado las siguientes acciones en su relación con la directora? La directora reconoce mi trabajo"
     ENU84b                "De agosto de 2017 a la fecha, ¿con qué frecuencia se han presentado las siguientes acciones en su relación con la directora? La directora valora mi trabajo"
     ENU84c                "De agosto de 2017 a la fecha, ¿con qué frecuencia se han presentado las siguientes acciones en su relación con la directora? La directora es respetuosa conmigo"
     ENU84d                "De agosto de 2017 a la fecha, ¿con qué frecuencia se han presentado las siguientes acciones en su relación con la directora? La directora aplica las normas conmigo, igual que con mis compañeras"
     ENU84e                "De agosto de 2017 a la fecha, ¿con qué frecuencia se han presentado las siguientes acciones en su relación con la directora? Tengo comunicación clara y oportuna con la directora"
     ENU84f                "De agosto de 2017 a la fecha, ¿con qué frecuencia se han presentado las siguientes acciones en su relación con la directora? Tengo confianza en la directora para pedirle orientación sobre mi trabajo"
     ENU84g                "De agosto de 2017 a la fecha, ¿con qué frecuencia se han presentado las siguientes acciones en su relación con la directora? Me puedo acercar a la directora cuando se me presenta una dificultad con los padres de familia"
     WVARSTRR              "Identificador del pseudoestrato (1 a 100) definido para el cálculo de errores estándar con el método de remuestreo BRR"
     W_FGRR1               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR2               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR3               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR4               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR5               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR6               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR7               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR8               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR9               "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR10              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR11              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR12              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR13              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR14              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR15              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR16              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR17              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR18              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR19              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR20              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR21              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR22              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR23              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR24              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR25              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR26              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR27              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR28              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR29              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR30              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR31              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR32              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR33              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR34              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR35              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR36              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR37              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR38              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR39              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR40              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR41              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR42              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR43              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR44              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR45              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR46              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR47              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR48              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR49              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR50              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR51              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR52              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR53              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR54              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR55              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR56              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR57              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR58              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR59              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR60              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR61              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR62              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR63              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR64              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR65              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR66              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR67              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR68              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR69              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR70              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR71              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR72              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR73              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR74              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR75              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR76              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR77              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR78              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR79              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR80              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR81              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR82              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR83              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR84              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR85              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR86              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR87              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR88              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR89              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR90              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR91              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR92              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR93              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR94              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR95              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR96              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR97              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR98              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR99              "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     W_FGRR100             "Pesos muestrales para el cálculo de errores estándar (Método BRR)"
     VERSION               "Versión de la base de datos"
.

/***********************************************************************
/*       Etiquetas de valores.
/*
/**********************************************************************.

VALUE LABELS
     ID_ENT
                         1      "Aguascalientes"
                         2      "Baja California"
                         3      "Baja California Sur"
                         4      "Campeche"
                         5      "Coahuila"
                         6      "Colima"
                         7      "Chiapas"
                         8      "Chihuahua"
                         9      "Ciudad de México"
                         10     "Durango"
                         11     "Guanajuato"
                         12     "Guerrero"
                         13     "Hidalgo"
                         14     "Jalisco"
                         15     "México"
                         16     "Michoacán"
                         17     "Morelos"
                         18     "Nayarit"
                         19     "Nuevo León"
                         20     "Oaxaca"
                         21     "Puebla"
                         22     "Querétaro"
                         23     "Quintana Roo"
                         24     "San Luis Potosí"
                         25     "Sinaloa"
                         26     "Sonora"
                         27     "Tabasco"
                         28     "Tamaulipas"
                         29     "Tlaxcala"
                         30     "Veracruz"
                         31     "Yucatán"
                         32     "Zacatecas"/
     ID_PREESTRATO
                         1       "Cursos Comunitarios"
                         2       "Gral Unidocente"
                         3       "Gral No Unidocente"
                         4       "Indígena Unidocente"
                         5       "Indígena No Unidocente"
                         6       "Privadas"/
     ID_TURNO
                         1      "Matutino"
                         2      "Vespertino"
                         3      "Nocturno"
                         4      "Discontinuo"
                         5      "Tiempo Completo"
                         6      "Complementario"
                         7      "Jornada Ampliada"
                         8      "Continuo"/
     ENU01a
     ENU01b
     ENU01c              1       "Si"
                         2       "No"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU02a
     ENU02b
     ENU03
                         992     "No aplica"
                         996     "Valor Inconsistente"
                         999     "Respuesta Omitida"/
     ENU04
                         997     "No Administrado"
                         999     "Respuesta Omitida"/
     ENU04_1             1       "Sí"
                         2       "No"
                         3       "No tengo la información"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU05
     ENU05a
     ENU05b
     ENU06
     ENU06a
     ENU06b
     ENU07
     ENU08
                         993     "No aplica por pregunta filtro"
                         996     "Valor Inconsistente"
                         997     "No Administrado"
                         999     "Respuesta Omitida"/
     ENU09               1       "grande para el número de niñas y niños que tengo"
                         2       "adecuado al número de niñas y niños que tengo"
                         3       "pequeño para el número de niñas y niños que tengo"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU10
     ENU11               1       "Si"
                         2       "No"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU12               1       "Sí, y lo tengo"
                         2       "Sí, y no lo tengo o no funciona"
                         3       "No se requiere"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU13
     ENU14               1       "Si"
                         2       "No"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU15               1       "Mucho"
                         2       "Regular"
                         3       "Poco"
                         4       "Nada"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU16a
     ENU16b              1       "Buenas condiciones: sin deterioro y sin riesgo"
                         2       "Condiciones regulares: presenta algún deterioro, pero sin riesgo"
                         3       "Malas condiciones: presenta deterioro y representa un riesgo"
                         4       "No hay"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU16c              1       "Buenas condiciones: sin deterioro y sin riesgo"
                         2       "Condiciones regulares: presenta algún deterioro, pero sin riesgo"
                         3       "Malas condiciones: presenta deterioro y representa un riesgo"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU17               1       "Si"
                         2       "No"
                         3       "No hay pizarrón o pintarrón"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU18
     ENU19               1       "Todas"
                         2       "Más de la mitad"
                         3       "La mitad"
                         4       "Menos de la mitad"
                         5       "Ninguna"
                         6       "No hay sillas para niñas y niños"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU20               1       "Si"
                         2       "No"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU21
                         993     "No aplica por pregunta filtro"
                         996     "Valor Inconsistente"
                         999     "Respuesta Omitida"/
     ENU22
     ENU23               1       "Sí"
                         2       "No"
                         3       "No hay mesas para niñas y niños"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU24               1       "Todas"
                         2       "Más de la mitad"
                         3       "La mitad"
                         4       "Menos de la mitad"
                         5       "Ninguna"
                         6       "No hay mesas para niñas y niños"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU25               1       "Sí, del tamaño para un adulto"
                         2       "Sí, del tamaño para niñas y niños"
                         3       "No cuento con silla"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU26               1       "Buenas condiciones: La silla no presenta deterioro y su uso no representa riesgo"
                         2       "Condiciones regulares: La silla tiene algún deterioro, pero su uso no implica riesgo"
                         3       "Malas condiciones: La silla tiene deterioro y su uso representa riesgo"
                         4       "No cuento con silla"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU27               1       "Sí, del tamaño para un adulto"
                         2       "Sí, del tamaño para niñas y niños"
                         3       "No cuento con escritorio o mesa"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU28               1       "Buenas condiciones: El escritorio o la mesa no presenta deterioro y su uso no representa riesgo"
                         2       "Condiciones regulares: El escritorio o la mesa tiene algún deterioro, pero su uso no implica riesgo"
                         3       "Malas condiciones: El escritorio o la mesa tiene deterioro y su uso representa riesgo"
                         4       "No cuento con escritorio o mesa"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU29               1       "Sí, es suficiente"
                         2       "Sí, pero no es suficiente"
                         3       "No cuento con mobiliario para organizar o guardar el material didáctico o equipo"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU30               1       "Buenas condiciones: El... (ver cuestionario .pdf)"
                         2       "Condiciones regulares: El... (ver cuestionario .pdf)"
                         3       "Malas condiciones: El... (ver cuestionario .pdf)"
                         4       "No cuento con mobiliario... (ver cuestionario .pdf)"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU31               1       "Sí, impreso por la SEP (CONALITEG)"
                         2       "Sí, en formato digital"
                         3       "Sí, en fotocopias"
                         4       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU32
     ENU32_1a
     ENU32_1b
     ENU32_1c
     ENU32_1d
     ENU32_1e
     ENU33               1       "Sí"
                         2       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU34
                         9993    "No aplica por pregunta filtro"
                         9999    "Respuesta Omitida"/
     ENU35               1       "Todos"
                         2       "Más de la mitad"
                         3       "La mitad"
                         4       "Menos de la mitad"
                         5       "Ninguno"
                         93      "No aplica por pregunta filtro"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU36a
     ENU36b
     ENU36c
     ENU36d
     ENU36e
     ENU36f
     ENU36g
     ENU36h
     ENU36i
     ENU36j
     ENU36k
     ENU36l
     ENU36m
     ENU36n              1       "Suficiente"
                         2       "Insuficiente"
                         3       "No existe el material"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU37a
     ENU37b
     ENU37c
     ENU37d
     ENU37e              999     "Respuesta Omitida"/
     ENU38a
     ENU38b
     ENU38c
     ENU38d
     ENU38e
     ENU38f
     ENU38g              1       "Sí"
                         2       "No"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU39               1       "La elaboro de forma individual"
                         2       "La elaboramos entre varias docentes (en reuniones de: Consejo Técnico, Consejo Técnico Es... (ver cuestionario .pdf)"
                         3       "Utilizo la que me proporciona el preescolar, la supervisión, el capacitador tutor o el CONAFE"
                         4       "Utilizo una planificación o plan de trabajo elaborada por alguna editorial u otra persona"
                         5       "No utilizo planificación, plan o ficha de trabajo"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU40a
     ENU40b
     ENU40c
     ENU40d
     ENU40e
     ENU40f
     ENU40g
     ENU40h
     ENU40i
     ENU40j
     ENU40k
     ENU40l
     ENU40m
     ENU40n
     ENU40o              1       "Sí"
                         2       "No"
                         96      "Valor Inconsistente"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU41a
     ENU41b
     ENU41c
     ENU41d
     ENU41e
     ENU41f              1       "Casi todos los días"
                         2       "Una o dos veces a la semana"
                         3       "Una vez cada dos semanas"
                         4       "Una vez al mes"
                         5       "Nunca"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU42               1       "Vuelvo a explicar y doy ejemplos al grupo"
                         2       "Le pido que ponga más atención"
                         3       "Me acerco a la niña o el niño y le explico"
                         4       "Pido a otra niña o niño que le explique"
                         5       "Después de la clase pido apoyo a los padres de familia"
                         6       "Otra actividad"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU43a
     ENU43b
     ENU43c
     ENU43d
     ENU43e
     ENU44a
     ENU44b
     ENU44c
     ENU44d
     ENU44e
     ENU44f
     ENU44g
     ENU44h
     ENU44i
     ENU44j
     ENU44k
     ENU44l              1       "Casi todos los días"
                         2       "Una o dos veces a la semana"
                         3       "Una vez cada dos semanas"
                         4       "Una vez al mes"
                         5       "Nunca"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU45a
     ENU45b              1       "Sí"
                         2       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU46               1       "Entre las niñas y los niños del grupo y yo"
                         2       "Entre los padres de familia del grupo y yo"
                         3       "Yo lo elaboré"
                         4       "Entre las docentes del preescolar o lo elaboramos en la reunión de tutoría"
                         5       "La dirección o la supervisión del preescolar lo asignó o lo entregó el capacitador tutor"
                         6       "Otro"
                         7       "No existe reglamento del salón de clases"
                         93      "No aplica por pregunta filtro"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU47a
     ENU47b
     ENU47c
     ENU47d
     ENU47e
     ENU47f
     ENU47g
     ENU47h
     ENU47i
                         1       "Sí"
                         2       "No"
                         93      "No aplica por pregunta filtro"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU48a
     ENU48b
     ENU48c
     ENU48d
     ENU48e
     ENU48f
     ENU48g
     ENU48h
     ENU48i
     ENU49a
     ENU49b
     ENU49c
     ENU49d
     ENU49e
     ENU49f
     ENU49g
     ENU50               1       "Todos"
                         2       "Más de la mitad"
                         3       "La mitad"
                         4       "Menos de la mitad"
                         5       "Ninguno"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU51               1       "Sí"
                         2       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU52a              1       "En mi grupo nadie habla una lengua indígena"
                         2       "En mi grupo alguien habla una lengua indígena"
                         93      "No aplica por pregunta filtro"/
     ENU52b
     ENU52c
     ENU52d
     ENU52e              1       "Totalmente"
                         2       "Suficiente"
                         3       "Poco"
                         4       "Nada"
                         93      "No aplica por pregunta filtro"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU53
                         993     "No aplica por pregunta filtro"
                         997     "No Administrado"
                         999     "Respuesta Omitida"/
     ENU54               1       "Sí"
                         2       "No"
                         93      "No aplica por pregunta filtro"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU55a
     ENU55b
     ENU55c              1       "Sí, impreso por la SEP (CONALITEG)"
                         2       "Sí, en formato digital"
                         3       "Sí, en fotocopias"
                         4       "No"
                         93      "No aplica por pregunta filtro"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU56a
     ENU56b
     ENU56c
     ENU56d
     ENU56e
     ENU56f              1       "Sí"
                         2       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU57a
     ENU57b
     ENU57c
     ENU57d
     ENU57e
     ENU57f
     ENU57g
     ENU57h
     ENU57i              1       "Siempre"
                         2       "Casi siempre"
                         3       "Algunas veces"
                         4       "Casi nunca"
                         5       "Nunca"
                         6       "Esta actividad no se realiza en este preescolar"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU58a
     ENU58b
     ENU58c
     ENU58d
     ENU58e
     ENU58f
     ENU59
     ENU60a
     ENU60b
     ENU60c
     ENU60d
     ENU60e
     ENU60f
     ENU61a
     ENU61b
     ENU61c
     ENU61d
     ENU61e
     ENU61f
     ENU61g
     ENU61h
     ENU61i
     ENU61j
     ENU61k
     ENU61l
     ENU61m
     ENU61n
     ENU61o
     ENU61_1a
     ENU61_1b
     ENU61_1c
     ENU61_1d
     ENU61_1e
     ENU61_1f
     ENU61_1g
     ENU61_1h
     ENU61_1i
     ENU61_1j
     ENU61_1k
     ENU61_1l
     ENU61_1m
     ENU61_1n
     ENU61_1o
     ENU62a
     ENU62b
     ENU62c              1       "Sí"
                         2       "No"
                         93      "No aplica por pregunta filtro"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU63
                         997     "No Administrado"
                         999     "Respuesta Omitida"/
     ENU63_1
     ENU64a
     ENU64b
     ENU64c
     ENU64d
     ENU64e
     ENU64f
     ENU64g
     ENU64h
     ENU64i
     ENU64j
     ENU64k
     ENU64_1a
     ENU64_1b
     ENU64_1c
     ENU64_1d
     ENU64_1e
     ENU64_1f
     ENU64_1g
     ENU64_1h
     ENU64_1i
     ENU64_1j
     ENU64_1k            1       "Sí"
                         2       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU64_2             1       "Más de 7"
                         2       "7"
                         3       "6"
                         4       "5"
                         5       "4"
                         6       "3"
                         7       "2"
                         8       "1"
                         9       "Menos de 1"
                         10      "No tuve capacitación inicial"
                         97      "No Administrado"
                         98      "Respuesta Múltiple"
                         99      "Respuesta Omitida"/
     ENU64_3             1       "Sí"
                         2       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU65               1       "hombre"
                         2       "mujer"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU66
                         996     "Valor Inconsistente"
                         999     "Respuesta Omitida"/
     ENU67
     ENU68a
     ENU68b
     ENU68c              1       "Sí"
                         2       "No"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU69
     ENU70               1       "Sí"
                         2       "Sí, en parte"
                         3       "No"
                         4       "No sé"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU71               1       "Bachillerato o preparatoria"
                         2       "Carrera Técnica o Técnico Superior"
                         3       "Normal básica sin licenciatura (antes de 1984)"
                         4       "Licenciatura"
                         5       "Maestría"
                         6       "Doctorado"
                         7       "Secundaria"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU72               1       "Licenciatura en Educación Preescolar"
                         2       "Licenciatura en Educación Preescolar para el Medio Indígena"
                         3       "Licenciatura en Educación Primaria o Primaria Indígena"
                         4       "Licenciatura relacionada con Educación Inicial, Especial o Básica"
                         5       "Otra licenciatura en educación (Pedagogía, Ciencias de la Educación, Psicopedagogía, Psicología Educativa u otra)"
                         6       "Otra licenciatura en área no educativa (Administración, Sociología u otra)"
                         7       "No tengo certificado o título de la licenciatura"
                         97      "No Administrado"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU73               1       "Licenciatura en Educación Preescolar"
                         2       "Licenciatura en Educación Preescolar para el Medio Indígena"
                         3       "Licenciatura en educación distinta al nivel Preescolar"
                         4       "Especialidad en área educativa"
                         5       "Diplomado en área educativa"
                         6       "Maestría en área educativa"
                         7       "Doctorado en área educativa"
                         8       "Otros estudios no relacionados con la educación"
                         9       "No estoy estudiando en la actualidad"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU73_1             1       "Bachillerato"
                         2       "Carrera Técnica o Técnico Superior"
                         3       "Licenciatura"
                         4       "Maestría"
                         5       "Otros estudios"
                         6       "No estoy estudiando en la actualidad"
                         97      "No Administrado"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU74
     ENU75
                         996     "Valor Inconsistente"
                         997     "No Administrado"
                         999     "Respuesta Omitida"/
     ENU75_1             1       "En agosto de 2017"
                         2       "En septiembre de 2017"
                         3       "En octubre de 2017"
                         97      "No Administrado"
                         98      "Respuesta Múltiple"
                         99      "Respuesta Omitida"/
     ENU75_2             1       "Sólo este ciclo"
                         2       "2 ciclos"
                         3       "3 ciclos o más"
                         97      "No Administrado"
                         98      "Respuesta Múltiple"
                         99      "Respuesta Omitida"/
     ENU75_3             1       "Sólo este ciclo"
                         2       "Desde hace 2 ciclos"
                         3       "Desde hace 3 ciclos o más"
                         97      "No Administrado"
                         98      "Respuesta Múltiple"
                         99      "Respuesta Omitida"/
     ENU75_4             1       "Sólo en esta comunidad"
                         2       "En 2"
                         3       "En 3"
                         4       "En más de 3"
                         97      "No Administrado"
                         98      "Respuesta Múltiple"
                         99      "Respuesta Omitida"/
     ENU76               1       "Nombramiento definitivo o de base (escuela pública)"
                         2       "Interino ilimitado (escuela pública)"
                         3       "Interino limitado (escuela pública)"
                         4       "Contratación por tiempo indefinido (escuela privada)"
                         5       "Contratación por tiempo determinado, honorarios o eventual (escuela pública o privada)"
                         6       "Dueña de la escuela (escuela privada)"
                         7       "Otro"
                         8       "No sé"
                         97      "No Administrado"
                         96      "Valor Inconsistente"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU77               1       "Por asignación directa de la autoridad educativa estatal o federal"
                         2       "Por concurso estatal (antes del 2014)"
                         3       "Por asignación sindical"
                         4       "Por concurso del Servicio Profesional Docente"
                         5       "Otro"
                         6       "No tengo plaza docente (soy interina)"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU78a
     ENU78b
     ENU78c
     ENU78d
     ENU78e
     ENU78f
     ENU78g
     ENU78h              1       "Sí"
                         2       "No"
                         96      "Valor Inconsistente"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU79
                         992     "No aplica"
                         996     "Valor Inconsistente"
                         999     "Respuesta Omitida"/
     ENU80               1       "Sí"
                         2       "No"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU81
                         993     "No aplica por pregunta filtro"
                         997     "No Administrado"
                         999     "Respuesta Omitida"/
     ENU82a
     ENU82b
     ENU82c
     ENU82d
     ENU82e
     ENU82f
     ENU82g
     ENU82h
     ENU82i
     ENU82j
     ENU82k
     ENU83a
     ENU83b
     ENU83c
     ENU83d
     ENU83e
     ENU83f
     ENU83g
     ENU83h              1       "Sí"
                         2       "No"
                         93      "No aplica por pregunta filtro"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
     ENU84a
     ENU84b
     ENU84c
     ENU84d
     ENU84e
     ENU84f
     ENU84g              1       "Siempre"
                         2       "Casi siempre"
                         3       "Algunas veces"
                         4       "Casi nunca"
                         5       "Nunca"
                         93      "No aplica por pregunta filtro"
                         97      "No Administrado"
                         98      "Respuesta múltiple"
                         99      "Respuesta Omitida"/
 .


/***********************************************************************
/* Declaración de valores Perdidos.
/*
/**********************************************************************.

MISSING VALUES ENU01a TO ENU01c (98,99).
MISSING VALUES ENU02a TO ENU04 (992 TO 999).
MISSING VALUES ENU04_1 (97,98,99).
MISSING VALUES ENU05 TO ENU08 (993 TO 999).
MISSING VALUES ENU09 TO ENU20 (96,98,99).
MISSING VALUES ENU21 (993,996,999).
MISSING VALUES ENU22 TO ENU33 (96 TO 99).
MISSING VALUES ENU34 (9993,9999).
MISSING VALUES ENU35 TO ENU36n (93,98,99).
MISSING VALUES ENU37a TO ENU37e (999).
MISSING VALUES ENU38a TO ENU52e (93 TO 99).
MISSING VALUES ENU53 (993,997,999).
MISSING VALUES ENU54 TO ENU62c (93 TO 99).
MISSING VALUES ENU63 (997,999).
MISSING VALUES ENU63_1 TO ENU65 (97,98,99).
MISSING VALUES ENU66 (996,999).
MISSING VALUES ENU67 TO ENU73_1 (97,98,99).
MISSING VALUES ENU74 TO ENU75 (996,997,999).
MISSING VALUES ENU75_1 TO ENU78h (96 TO 99).
MISSING VALUES ENU79 (992,996,999).
MISSING VALUES ENU80 (97,98,99).
MISSING VALUES ENU81 (993,997,999).
MISSING VALUES ENU82a TO ENU84g (93 TO 99).
EXECUTE.



